
import { Button } from "@/components/ui/button"
import { ArrowRight, Play, MessageSquare, Zap, Sparkles } from "lucide-react"

const HeroSection = () => {
  return (
    <section id="home" className="relative h-screen flex items-center justify-center overflow-hidden hero-gradient grain">
      {/* Background grid */}
      <div className="absolute inset-0 grid-glow opacity-30"></div>
      
      {/* Floating elements */}
      {/* <div className="absolute top-20 left-10 w-20 h-20 bg-foreground/5 rounded-full blur-xl animate-pulse"></div>
      <div className="absolute bottom-20 right-10 w-32 h-32 bg-foreground/5 rounded-full blur-xl animate-pulse delay-700"></div>
      <div className="absolute top-1/2 left-20 w-16 h-16 bg-foreground/5 rounded-full blur-xl animate-pulse delay-1000"></div> */}

      <div className="relative z-10 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
        <div className="max-w-4xl mx-auto">
          {/* Badge */}
          <div className="inline-flex items-center space-x-2 border border-yellow-500/50 glassmorphic rounded-full px-4 py-2 mb-8 hover-scale">
            <Sparkles className="h-4 w-4 text-yellow-500" />
            <span className="text-sm font-medium">Now in Beta</span>
          </div>

          {/* Main headline */}
          <h1 className="text-2xl md:text-6xl font-light text-gray-900 dark:text-white mb-6 leading-tight">
            <span className="text-foreground">
              Monetize Your AI Ideas.
            </span>
            <br />
            <span className="text-foreground/70">No Code Needed.</span>
          </h1>

          {/* Subtext */}
          <p className="text-lg md:text-xl text-foreground/70 mb-12 max-w-3xl mx-auto leading-relaxed">
            Create, deploy, and sell Everyday Series and MCPs—whether you're a dev or not. 
            Turn your AI concepts into revenue streams with our powerful platform.
          </p>

          {/* CTA Buttons */}
          <div className="flex flex-col sm:flex-row items-center justify-center space-y-4 sm:space-y-0 sm:space-x-6 mb-16">
            <Button
              size="lg"
              className="bg-foreground text-background hover:bg-foreground/90 px-8 py-4 text-lg font-semibold btn-hover-scale group"
            >
              <Zap className="h-5 w-5 mr-2 text-yellow-500 group-hover:animate-pulse" />
              Start Building
              <ArrowRight className="h-5 w-5 ml-2 group-hover:translate-x-1 transition-transform" />
            </Button>
            
            <Button
              variant="outline"
              size="lg"
              className="glassmorphic px-8 py-4 text-lg font-semibold btn-outline-fill group border-foreground/20"
            >
              <Play className="h-5 w-5 mr-2" />
              See Examples
            </Button>
          </div>

          {/* ChatGPT-style interface preview */}
          <div className="relative max-w-4xl mx-auto hover-scale dark:border rounded-lg">
            <div className="glassmorphic rounded-2xl p-6 shadow-2xl">
              <div className="flex items-center space-x-3 mb-4">
                <div className="flex space-x-2">
                  <div className="w-3 h-3 bg-red-500 rounded-full"></div>
                  <div className="w-3 h-3 bg-yellow-500 rounded-full"></div>
                  <div className="w-3 h-3 bg-green-500 rounded-full"></div>
                </div>
                <div className="text-sm text-foreground/60">MCP Chat Interface</div>
              </div>
              
              <div className="space-y-4">
                <div className="flex items-start space-x-3">
                  <div className="w-8 h-8 bg-foreground/10 rounded-full flex items-center justify-center">
                    <MessageSquare className="h-4 w-4 text-foreground" />
                  </div>
                  <div className="flex-1 glassmorphic rounded-lg p-4">
                    <p className="text-sm text-left text-foreground/80">
                      "Create a trading bot that monitors crypto prices and executes trades based on technical indicators"
                    </p>
                  </div>
                </div>
                
                <div className="flex items-start space-x-3">
                  <div className="w-8 h-8 bg-foreground/10 rounded-full flex items-center justify-center">
                    <Zap className="h-4 w-4 text-foreground" />
                  </div>
                  <div className="flex-1 glassmorphic rounded-lg p-4">
                    <p className="text-sm text-left text-foreground/80">
                      ✨ Perfect! I've created your trading bot MCP. It's now live and earning $2.50 per execution. <br />
                      <span className="text-foreground font-semibold">Revenue this month: $847</span>
                    </p>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  )
}

export default HeroSection
