
import React from 'react';
import { Button } from '@/components/ui/button';
import { FiX } from 'react-icons/fi';

interface SidebarPanelProps {
  isOpen: boolean;
  content: any;
  onClose: () => void;
}

const SidebarPanel: React.FC<SidebarPanelProps> = ({ isOpen, content, onClose }) => {
  return (
    <div
      className={`fixed right-0 top-10 h-[calc(100vh-80px)] w-2/5 rounded-3xl shadow-md transform transition-transform duration-500 ease-in-out z-40 ${
        isOpen ? 'translate-x-0' : 'translate-x-full'
      }`}
    >
      <div className="h-full rounded-3xl border-l border-gray-200/10 dark:border-gray-700/10 backdrop-blur-xl bg-white/90 dark:bg-black/90">
        <div className="p-8 h-full overflow-y-auto">
          <div className="flex items-center justify-between mb-8">
            <h2 className="text-2xl font-medium text-gray-900 dark:text-white">
              {content?.title || 'Details'}
            </h2>
            <Button
              variant="ghost"
              onClick={onClose}
              className="w-10 h-10 rounded-xl hover:bg-gray-100 dark:hover:bg-gray-800 transition-colors"
            >
              <FiX className="w-5 h-5" />
            </Button>
          </div>

          {content && (
            <div className="space-y-6">
              {content.component}
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default SidebarPanel;
