import React from 'react';
import { FiGithub, FiLinkedin, FiMail } from 'react-icons/fi';

const developers = [
  {
    name: "Ben Johnson",
    role: "Founder & Lead Engineer",
    github: "https://github.com/bjohnson-dev",
    linkedin: "https://linkedin.com/in/benjohnson-dev",
    email: "mailto:benn@fastcode.ai",
    avatar: "https://randomuser.me/api/portraits/men/32.jpg"
  },
  {
    name: "Cayla Hawkins",
    role: "Full Stack Developer",
    github: "https://github.com/caylacodes",
    linkedin: "https://linkedin.com/in/caylahawkins",
    email: "mailto:cayla@fastcode.ai",
    avatar: "https://randomuser.me/api/portraits/women/66.jpg"
  },
  {
    name: "Toby Schmidt",
    role: "AI/ML Engineer",
    github: "https://github.com/tobeyy",
    linkedin: "https://linkedin.com/in/schmidttoby",
    email: "mailto:toby@fastcode.ai",
    avatar: "https://randomuser.me/api/portraits/men/78.jpg"
  },
  {
    name: "Sara Lee",
    role: "Frontend Developer",
    github: "https://github.com/saralee",
    linkedin: "https://linkedin.com/in/saralee",
    email: "mailto:sara@fastcode.ai",
    avatar: "https://randomuser.me/api/portraits/women/60.jpg"
  }
];

const Developers = () => {
  return (
    <div className="space-y-8">
      <div className="space-y-4">
        <h3 className="text-xl font-semibold text-gray-900 dark:text-white">
          Meet the Developers Behind Fastcode
        </h3>
        <p className="text-gray-600 dark:text-gray-300 leading-relaxed">
          The Fastcode platform is built and maintained by a passionate team of engineers and creators.
        </p>
      </div>

      <div className="grid gap-6 md:grid-cols-2">
        {developers.map((dev) => (
          <div
            key={dev.email}
            className="flex items-center gap-5 p-6 rounded-2xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/5 dark:bg-black/5 hover:scale-105 transition-all duration-300"
          >
            <img
              src={dev.avatar}
              alt={dev.name}
              className="w-16 h-16 rounded-full object-cover border-2 border-gray-300 dark:border-gray-700"
            />
            <div className="flex-1">
              <h4 className="font-medium text-gray-900 dark:text-white">{dev.name}</h4>
              <div className="text-sm text-gray-600 dark:text-gray-300 mb-2">{dev.role}</div>
              <div className="flex gap-3">
                <a href={dev.github} target="_blank" rel="noopener noreferrer" aria-label="GitHub">
                  <FiGithub className="w-5 h-5 text-gray-700 dark:text-gray-300 hover:text-black dark:hover:text-white" />
                </a>
                <a href={dev.linkedin} target="_blank" rel="noopener noreferrer" aria-label="LinkedIn">
                  <FiLinkedin className="w-5 h-5 text-blue-700 dark:text-blue-400 hover:text-blue-900" />
                </a>
                <a href={dev.email} aria-label="Email">
                  <FiMail className="w-5 h-5 text-gray-700 dark:text-gray-300 hover:text-black dark:hover:text-white" />
                </a>
              </div>
            </div>
          </div>
        ))}
      </div>
    </div>
  );
};

export default Developers;