import React, { useEffect, useState } from 'react';
import { generateResponse } from '@/services/geminiService';

interface DynamicContentProps {
  content: any;
}

const DynamicContent: React.FC<DynamicContentProps> = ({ content }) => {
  const [geminiAnswer, setGeminiAnswer] = useState<string | null>(null);
  const [loading, setLoading] = useState(false);

  useEffect(() => {
    const fetchGemini = async () => {
      if (content?.type === 'gemini' && content.prompt) {
        setLoading(true);
        const res = await generateResponse(content.prompt, []);
        setGeminiAnswer(res.message);
        setLoading(false);
      }
    };
    fetchGemini();
  }, [content]);

  if (!content) return null;

  if (content.type === 'gemini') {
    return (
      <div className="p-6">
        <h3 className="text-lg font-semibold mb-4">Gemini Answer</h3>
        {loading ? (
          <div className="text-gray-500">Loading...</div>
        ) : (
          <div className="text-gray-900 dark:text-white whitespace-pre-line">{geminiAnswer}</div>
        )}
      </div>
    );
  }

  // If content is a React node/component, render it
  if (React.isValidElement(content)) return content;

  // Fallback: render as text
  return (
    <div className="p-6 text-gray-900 dark:text-white">
      {typeof content === 'string' ? content : JSON.stringify(content)}
    </div>
  );
};

export default DynamicContent;